Learn R Programming

Rxnat (version 1.0.15)

xnat_connection: Make a connection to an XNAT server

Description

Make the XNAT connection and provides functions to retrieve the list of projects, experiments and subjects.

Usage

xnat_connect(base_url, username = NULL, password = NULL, xnat_name = NULL, ...)

Arguments

base_url

the URL for the XNAT server

username

user name to use for connection. If NULL this can be provided through the xxx_WEB_USER system variable where xxx is provided by the xnat_name parameter

password

user name to use for connection. If NULL this can be provided through the xxx_WEB_PASS system variable where xxx is provided by the xnat_name parameter

xnat_name

prefix to use for retrieving the proper username/pass system variables for a specific XNAT server

...

additional arguments passed to curlPerform.

Value

projects

Examples

Run this code
# NOT RUN {
## Connect to the NITRC.ORG database
# }
# NOT RUN {
xnat_connect('https://nitrc.org/ir', xnat_name='NITRC')
# }
# NOT RUN {
## Connect to the XNAT.CENTRAL database
# }
# NOT RUN {
xnat_connect('https://central.xnat.org', xnat_name="CENTRAL")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab